# boorukits

![Github Actions pytest](https://img.shields.io/github/workflow/status/MaikoTan/boorukits/pytest?label=pytest)
[![GitHub release](https://img.shields.io/github/v/release/MaikoTan/boorukits?include_prereleases&style=plastic)](https://github.com/MaikoTan/boorukits/releases/latest)
[![Pypi package](https://img.shields.io/pypi/v/boorukits)](https://pypi.org/project/boorukits/)

boorukits is an unofficial asynchronous library for fetching images from booru-like gallery (eg. Danbooru/Moebooru)

## WORK IN PROGRESS

**This project is not stable now.**

It is **NOT** recommanded to use it in production.

## Usage

(Coming soon...)
